package com.ruoyi.system.service.columns;

import com.ruoyi.system.domain.columns.YjInherit;

import java.util.List;

/**
 * 瑜伽传承Service接口
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
public interface IYjInheritService 
{
    /**
     * 查询瑜伽传承
     * 
     * @param id 瑜伽传承主键
     * @return 瑜伽传承
     */
    public YjInherit selectYjInheritById(String id);

    /**
     * 查询瑜伽传承列表
     * 
     * @param yjInherit 瑜伽传承
     * @return 瑜伽传承集合
     */
    public List<YjInherit> selectYjInheritList(YjInherit yjInherit);

    /**
     * 新增瑜伽传承
     * 
     * @param yjInherit 瑜伽传承
     * @return 结果
     */
    public int insertYjInherit(YjInherit yjInherit);

    /**
     * 修改瑜伽传承
     * 
     * @param yjInherit 瑜伽传承
     * @return 结果
     */
    public int updateYjInherit(YjInherit yjInherit);

    /**
     * 批量删除瑜伽传承
     * 
     * @param ids 需要删除的瑜伽传承主键集合
     * @return 结果
     */
    public int deleteYjInheritByIds(String[] ids);

    /**
     * 删除瑜伽传承信息
     * 
     * @param id 瑜伽传承主键
     * @return 结果
     */
    public int deleteYjInheritById(String id);
}
